@@ -49,7 +49,6 @@ void htmlrel()
    char *s;
    int  x, count;
 
-   if(indexonly) return;
    if(strstr(ReportType,"users_sites") == 0) return;
 
    strcpy(tmp2,TempDir);
@@ -59,7 +58,7 @@ void htmlrel()
    strcat(tmp3,"/sargtmp.log");
 
    strcpy(arqper,dirname);
-   strcat(arqper,"/period");
+   strcat(arqper,"/sarg-period");
 
    if ((fp_in = fopen(arqper, "r")) == 0){
       fprintf(stderr, "SARG: (html1) %s: %s\n",text[45],arqper);
@@ -70,7 +69,7 @@ void htmlrel()
    fclose(fp_in);
 
    strcpy(arqper,dirname);
-   strcat(arqper,"/general");
+   strcat(arqper,"/sarg-general");
 
    if ((fp_in = fopen(arqper, "r")) == 0){
       fprintf(stderr, "SARG: (html2) %s: %s\n",text[45],arqper);
@@ -335,7 +334,7 @@ void htmlrel()
          twork=my_atoll(nacc);
          sprintf(wwork1,"%s",fixnum(twork,1));
          sprintf(wwork2,"%s",fixnum(nnbytes,1));
-         sprintf(wwork3,"%s",fixnum(nnelap,1));
+         sprintf(wwork3,"%s",fixnum2(nnelap,1));
 
          if(strcmp(LongUrl,"yes") != 0) {
             getword(warea,url,'/');
@@ -545,7 +544,7 @@ void htmlrel()
    
       sprintf(wwork1,"%s",fixnum(tnacc,1));
       sprintf(wwork2,"%s",fixnum(tnbytes,1));
-      sprintf(wwork3,"%s",fixnum(tnelap,1));
+      sprintf(wwork3,"%s",fixnum2(tnelap,1));
 
       sprintf(val2,"%s%s",href2,ltext110);
       sprintf(val3,"%3.2f%%",perc);
@@ -640,8 +639,14 @@ void htmlrel()
          }
       }
 
+//      if(indexonly) {
+//	unlink(arqou);
+//	continue;
+//      }
+
+   if (strstr(ReportType,"topuser") != 0) {
       strcpy(arqper,dirname);
-      strcat(arqper,"/users");
+      strcat(arqper,"/sarg-users");
  
       if ((fp_in = fopen(arqper, "r")) == 0){
          fprintf(stderr, "SARG: (html11) %s: %s\n",text[45],arqper);
@@ -669,7 +674,7 @@ void htmlrel()
   
       sprintf(wwork1,"%s",fixnum(twork,1));
       sprintf(wwork2,"%s",fixnum(totbytes2,1));
-      sprintf(wwork3,"%s",fixnum(totelap2,1));
+      sprintf(wwork3,"%s",fixnum2(totelap2,1));
 
       sprintf(val6,"%s",buildtime(totelap2));
       sprintf(val7,"%3.2f%%",perc2); 
@@ -706,7 +711,7 @@ void htmlrel()
          sprintf(html,"<tr><th></th><th %s>%s</th><th %s>%s</th><th %s>%s</th><th></th><th></th><th></th><th %s>%s</th><th %s>%s</font></th><th %s>%s</th></tr>\n",hbc6,text[96],hbc1,wwork1,hbc2,wwork2,hbc4,val6,hbc3,wwork3,hbc5,val7);
          fputs(html,fp_ou);
       }
-
+} /* added */
       tnacc=0;
       tnbytes=0;
       tnelap=0;
