@@ -1,6 +1,6 @@
 /*
  * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
- *                                                            1998, 2007
+ *                                                            1998, 2008
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -531,7 +531,7 @@ int main(argc,argv)
       strcat(tmp2,"/sarg");
       strcpy(outdir,tmp2);
       strcat(outdir,"/");
-    }
+   }
 
    strcat(tmp2,"/sarg.log");
 
@@ -1409,11 +1409,10 @@ int main(argc,argv)
       recomp(arq, zip); }
 //   else  unlink(arq);
 
-   if(debug)
-      debuga(text[21]);
-
-   sprintf(csort,"rm -rf %s",tmp);
-   system(csort);
+   if(strcmp(tmp,"/tmp") != 0) {
+      sprintf(tmp4,"rm -rf %s",tmp);
+      system(tmp4);
+   }
 
    if(excludecode)
       free(excludecode);
@@ -1424,6 +1423,9 @@ int main(argc,argv)
    if(excludeuser)
       free(excludeuser);
 
+   if(debug)
+      debuga(text[21]);
+
    exit(0);
 
 }
