@@ -1,6 +1,6 @@
 /*
  * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
- *                                                            1998, 2007
+ *                                                            1998, 2008
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -409,12 +409,12 @@ void fixip(char *ip)
 
 
 char *fixnum(long long int value, int n)
-#define MAXIMO 1024
+#define MAXLEN 1024
 {
-   char num[MAXIMO];
-   char buf[MAXIMO * 2];
+   char num[MAXLEN];
+   char buf[MAXLEN * 2];
    char *pbuf;
-   char ret[MAXIMO * 2];
+   static char ret[MAXLEN * 2];
    char *pret;
    register int i, j, k;
    static char abbrev[30];
@@ -470,7 +470,7 @@ char *fixnum(long long int value, int n)
       return(abbrev);
    }
 
-   bzero(buf, MAXIMO*2);
+   bzero(buf, MAXLEN*2);
 
    pbuf = buf;
    pret = ret;
@@ -502,18 +502,18 @@ char *fixnum(long long int value, int n)
 
 
 char *fixnum2(long long int value, int n)
-#define MAXIMO 1024
+#define MAXLEN 1024
 {
-   char num[MAXIMO];
-   char buf[MAXIMO * 2];
+   char num[MAXLEN];
+   char buf[MAXLEN * 2];
    char *pbuf;
-   char ret[MAXIMO * 2];
+   static char ret[MAXLEN * 2];
    char *pret;
    register int i, j, k;
    static char abbrev[30];
       
    my_lltoa(value, num, 0);
-   bzero(buf, MAXIMO*2);
+   bzero(buf, MAXLEN*2);
 
    pbuf = buf;
    pret = ret;
@@ -1259,6 +1259,23 @@ void write_html_header(FILE *fp_ou, char * ind)
    fprintf(fp_ou,"<center><table cellpadding=\"0\" cellspacing=\"0\">\n<tr><th class=\"title\">%s</th></tr>\n</table></center>\n<center><table cellpadding=\"1\" cellspacing=\"2\">\n<tr><td></td><td></td></tr>\n",Title);
 }
 
+void baddata()
+{
+   printf("SARG: ------------------------------------------------------------------------------\n");
+   printf("SARG: MALICIUS CODE DETECTED.\n");
+   printf("SARG: I think someone is trying to execute arbitrary code in your system using sarg.\n");
+   printf("SARG: please review your access.log and/or your useragent.log file.\n");
+   printf("SARG: process stoped. No actions taken.\n");
+   printf("SARG: ------------------------------------------------------------------------------\n");
+
+   system("rm -rf /tmp/sarg");
+   sprintf(tmp4,"rm -rf %s",dirname);
+   system(tmp4);
+   system("rm -rf /tmp/sarg");
+
+   exit(1);
+}
+
 
 char url_module(char *url, char *w2)
 {
